pub(crate) struct InstallConfiguration {
pub(crate) root_fs_type: Option<Filesystem>,
pub(crate) block: Option<Vec<BlockSetup>>,
pub(crate) filesystem: Option<BasicFilesystems>,
pub(crate) kargs: Option<Vec<String>>,
pub(crate) karg_deletes: Option<Vec<String>>,
pub(crate) match_architectures: Option<Vec<String>>,
pub(crate) ostree: Option<RepoOptions>,
pub(crate) stateroot: Option<String>,
pub(crate) root_mount_spec: Option<String>,
pub(crate) boot_mount_spec: Option<String>,
pub(crate) bootupd: Option<Bootupd>,
pub(crate) bootloader: Option<Bootloader>,
}Expand description
The serialized [install] section
Fields
root_fs_type: Option<Filesystem>Root filesystem type
block: Option<Vec<BlockSetup>>Enabled block storage configurations
filesystem: Option<BasicFilesystems>kargs: Option<Vec<String>>Kernel arguments, applied at installation time
karg_deletes: Option<Vec<String>>Deleting Kernel arguments, applied at installation time
match_architectures: Option<Vec<String>>Supported architectures for this configuration
ostree: Option<RepoOptions>Ostree repository configuration
stateroot: Option<String>The stateroot name to use. Defaults to default
root_mount_spec: Option<String>Source device specification for the root filesystem.
For example, UUID=2e9f4241-229b-4202-8429-62d2302382e1 or LABEL=rootfs.
boot_mount_spec: Option<String>Mount specification for the /boot filesystem.
bootupd: Option<Bootupd>Bootupd configuration
bootloader: Option<Bootloader>Bootloader to use (grub, systemd, none)
Implementations
Sourceimpl InstallConfiguration
impl InstallConfiguration
Sourcepub(crate) fn canonicalize(&mut self)
pub(crate) fn canonicalize(&mut self)
Set defaults (e.g. block), and also handle fields that can be specified multiple ways
by synchronizing the values of the fields to ensure they’re the same.
- install.root-fs-type is synchronized with install.filesystems.root.type; if both are set, then the latter takes precedence
Sourcepub(crate) fn filesystem_root(&self) -> Option<&RootFS>
pub(crate) fn filesystem_root(&self) -> Option<&RootFS>
Convenience helper to access the root filesystem
pub(crate) fn filter_to_external(&mut self)
pub(crate) fn get_block_setup( &self, default: Option<BlockSetup>, ) -> Result<BlockSetup>